@@ -1,9 +1,9 @@
 package Devel::Examine::Subs::Postprocessor;
-use 5.008;
+use 5.012;
 use strict;
 use warnings;
 
-our $VERSION = '1.57_01';
+our $VERSION = '1.46';
 
 use Carp;
 use Data::Dumper;
@@ -17,7 +17,7 @@ BEGIN {
         import Devel::Trace::Subs qw(trace);
     };
 
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
+    if ($@){
         *trace = sub {};
     }
 };
@@ -97,7 +97,7 @@ sub subs {
                 $s->{$f}{subs}{$sub}{start}++;
                 $s->{$f}{subs}{$sub}{end}++;
                 $s->{$f}{subs}{$sub}{name} = $sub;
-                @{ $s->{$f}{subs}{$sub}{code} } = @{ $s->{$f}{subs}{$sub}{code} };
+                @{ $s->{$f}{subs}{$sub}{file} } = @{ $s->{$f}{contents} };
                 push @subs, $s->{$f}{subs}{$sub};
             }
         }
@@ -131,7 +131,7 @@ sub file_lines_contain {
             for my $sub (keys %{$s->{$f}{subs}}){
                 my $found = 0;
                 my @has;
-                for (@{$s->{$f}{subs}{$sub}{code}}){
+                for (@{$s->{$f}{subs}{$sub}{contents}}){
                     if ($_ and /$search/){
                         $found++;
                         push @has, $_;
@@ -141,7 +141,7 @@ sub file_lines_contain {
                     delete $s->{$f}{subs}{$sub};                
                     next;
                 }
-                $s->{$f}{subs}{$sub}{code} = \@has;
+                $s->{$f}{subs}{$sub}{contents} = \@has;
             }
         }
         return $struct;
